# How to generate a PIP package?
- Change setup.cfg version
- py -m build
- py -m twine upload --skip-existing dist/*

Use this api key: pypi-AgEIcHlwaS5vcmcCJDJkYjRiNzE1LTU2NTEtNDc3MS1hOTJmLTljZTNhZWY5OGI0MAACFlsxLFsic2NyYXBlYW55dGhpbmciXV0AAixbMixbIjU3MTA5MDEwLTdmYTEtNGMzNi1hZGVhLTg1NGZiYmI0OWYwMyJdXQAABiCQutzsbQMU3UGxVyCcVLP2HxX0DvPENb1oEB-JoTt4pw

Reference: https://packaging.python.org/en/latest/tutorials/packaging-projects/